blochsimu
=========

Python package for simulating the Bloch equation for e.g. NMR-related simulations.

The simulator has been optimized to use effective array operations in numpy in preallocated memory buffers.

Installation
------------

Make sure you have the "pip" tool. Then type on the command line:

    pip install blochsimu

